==> ars_nouveau-1.19.1-3.2.9.187-sources.jar: com/hollingsworth/arsnouveau/common/entity/ChangeableBehavior.java <==
package com.hollingsworth.arsnouveau.common.entity;

import com.hollingsworth.arsnouveau.api.item.IWandable;
import net.minecraft.nbt.CompoundTag;
import net.minecraft.network.chat.Component;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.InteractionHand;
import net.minecraft.world.InteractionResult;
import net.minecraft.world.entity.Entity;
import net.minecraft.world.entity.ai.goal.WrappedGoal;
import net.minecraft.world.entity.item.ItemEntity;
import net.minecraft.world.entity.player.Player;
import net.minecraft.world.item.ItemStack;
import net.minecraft.world.level.Level;

import java.util.ArrayList;
import java.util.List;

public abstract class ChangeableBehavior implements IWandable {
    public List<WrappedGoal> goals = new ArrayList<>();

    public Level level;

    public Entity entity;

    public ChangeableBehavior(Entity entity, CompoundTag tag) {
        this.level = entity.level;
        this.entity = entity;
    }

    public void getTooltip(List<Component> tooltip){}

    public CompoundTag toTag(CompoundTag tag) {
        tag.putString("id", getRegistryName().toString());
        return tag;
    }

    public double getX(){
        return entity.getX();
    }

    public double getY(){
        return entity.getY();
    }

    public double getZ(){
        return entity.getZ();
    }

    public void pickUpItem(ItemEntity entity) {}

    protected abstract ResourceLocation getRegistryName();

    public InteractionResult mobInteract(Player player, InteractionHand hand) {
        return InteractionResult.PASS;
    }

    public ItemStack getStackForRender(){
        return ItemStack.EMPTY;
    }
}

==> ars_nouveau-1.19.2-3.13.4.477-sources.jar: com/hollingsworth/arsnouveau/common/entity/ChangeableBehavior.java <==
package com.hollingsworth.arsnouveau.common.entity;

import com.hollingsworth.arsnouveau.api.item.IWandable;
import net.minecraft.nbt.CompoundTag;
import net.minecraft.network.chat.Component;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.InteractionHand;
import net.minecraft.world.InteractionResult;
import net.minecraft.world.entity.Entity;
import net.minecraft.world.entity.ai.goal.WrappedGoal;
import net.minecraft.world.entity.item.ItemEntity;
import net.minecraft.world.entity.player.Player;
import net.minecraft.world.item.ItemStack;
import net.minecraft.world.level.Level;

import java.util.ArrayList;
import java.util.List;

public abstract class ChangeableBehavior implements IWandable {
    public List<WrappedGoal> goals = new ArrayList<>();

    public Level level;

    public Entity entity;

    public ChangeableBehavior(Entity entity, CompoundTag tag) {
        this.level = entity.level;
        this.entity = entity;
    }

    public void getTooltip(List<Component> tooltip){}

    public CompoundTag toTag(CompoundTag tag) {
        tag.putString("id", getRegistryName().toString());
        return tag;
    }

    public double getX(){
        return entity.getX();
    }

    public double getY(){
        return entity.getY();
    }

    public double getZ(){
        return entity.getZ();
    }

    public void pickUpItem(ItemEntity entity) {}

    protected abstract ResourceLocation getRegistryName();

    public InteractionResult mobInteract(Player player, InteractionHand hand) {
        return InteractionResult.PASS;
    }

    public ItemStack getStackForRender(){
        return ItemStack.EMPTY;
    }


    /**
     * @return true if onWanded can remove the current accessory, false if it only needs to reset connections
     */
    public boolean clearOrRemove() {
        return true;
    }
}
